<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInit796e60c4934c31d005a9908869db3d95
{
    public static $prefixesPsr0 = array (
        'P' => 
        array (
            'Phaxio\\' => 
            array (
                0 => __DIR__ . '/..' . '/phaxio/phaxio/lib',
            ),
            'Phaxio' => 
            array (
                0 => __DIR__ . '/..' . '/phaxio/phaxio/lib',
            ),
        ),
    );

    public static $classMap = array (
        'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixesPsr0 = ComposerStaticInit796e60c4934c31d005a9908869db3d95::$prefixesPsr0;
            $loader->classMap = ComposerStaticInit796e60c4934c31d005a9908869db3d95::$classMap;

        }, null, ClassLoader::class);
    }
}
